import rclpy
from rclpy.node import Node

from geometry_msgs.msg import Twist
from std_msgs.msg import String
from sensor_msgs.msg import Joy

import numpy as np


def calc_speed_from_joy(x, y):    
    linear = -y
    angular = -x

    return linear, angular

class TwistPublisher(Node):

    def __init__(self):
        super().__init__('twist_publisher')
        self.publisher_ = self.create_publisher(Twist, 'cmd_vel', 1)
        self.create_subscription(Joy, "/joy", self.joy_callback, 1)



    def joy_callback(self, joy_message):
        x, y = joy_message.axes[:2]

        linear, angular = calc_speed_from_joy(x,y)

        msg = Twist()
        msg.linear.x = linear
        msg.angular.z = angular
        self.publisher_.publish(msg)
        self.get_logger().info('Publishing: "%s"' % msg)


def main(args=None):
    rclpy.init(args=args)

    minimal_publisher = TwistPublisher()

    rclpy.spin(minimal_publisher)

    # Destroy the node explicitly
    # (optional - otherwise it will be done automatically
    # when the garbage collector destroys the node object)
    minimal_publisher.destroy_node()
    rclpy.shutdown()


if __name__ == '__main__':
    main()